@@ -2,27 +2,21 @@ package Template::Plugin::Comma;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.02;
+$VERSION = 0.03;
 
-require Template::Plugin::Filter;
-use base qw(Template::Plugin::Filter);
+require Template::Plugin;
+use base qw(Template::Plugin);
 
-use vars qw($DYNAMIC $FILTER_NAME);
-$DYNAMIC = 1;
+use vars qw($FILTER_NAME);
 $FILTER_NAME = 'comma';
 
-sub init {
-    my $self = shift;
-    my $name = $self->{_ARGS}->[0] || $FILTER_NAME;
-    $self->install_filter($name);
+sub new {
+    my($self, $context, @args) = @_;
+    my $name = $args[0] || $FILTER_NAME;
+    $context->define_filter($name, \&commify, 0);
     return $self;
 }
 
-sub filter {
-    my($self, $text, $args, $config) = @_;
-    return commify($text);
-}
-
 sub commify {
     local $_  = shift;
     1 while s/([-+]?\d+)(\d{3})/$1,$2/;
